Skip to main contentModule composer_context
Source - ComposerScopeGuard
- Guard that pops the composer stack on drop.
- current_composer
- Return the current composer from the thread-local stack.
- enter
- Pushes the composer onto the thread-local stack for the duration of the scope.
Returns a guard that will pop it on drop.
- try_with_composer
- Try to access the current composer from the thread-local stack.
Returns None if there is no active composer.
- with_composer
- Access the current composer from the thread-local stack.