pub fn DisposableEffect<K, F>(keys: K, effect: F)Expand description
Runs effect when this call site first enters composition, and again
whenever keys no longer equals the value it ran with last time; the
previous run’s DisposableEffectScope::on_dispose cleanup, if any,
runs first, and also when the call site leaves composition entirely.
keys may be a tuple to depend on more than one value, matching Jetpack
Compose’s DisposableEffect(vararg keys).