LaunchedEffect

Function LaunchedEffect 

pub fn LaunchedEffect<K, F>(keys: K, effect: F)
where K: PartialEq + 'static, F: FnOnce(LaunchedEffectScope) + 'static,
Runs effect when this call site first enters composition, and again whenever keys no longer equals the value it ran with last time.

keys may be a tuple to depend on more than one value, matching Jetpack Compose’s LaunchedEffect(vararg keys).