mutableStateOfNeverEqual

Function mutableStateOfNeverEqual 

pub fn mutableStateOfNeverEqual<T: Clone + 'static>(
    initial: T,
) -> MutableState<T>
Like mutableStateOf, for a value that cannot be compared or whose every write must count as a change.

This is Jetpack Compose’s neverEqualPolicy(), and the non-remembered form of rememberMutableStateOfNeverEqual.