Module runtime

Module runtime 

Structs

DefaultScheduler
Runtime
RuntimeDebugStats
RuntimeHandle
RuntimeId
RuntimeThreadLocalDebugStats
StateArenaDebugStats
StateId
TaskHandle
UiDispatcher

Functions

current_runtime_handle
Gets the current runtime handle from thread-local storage.
debug_runtime_thread_local_stats
schedule_frame
Schedule a new frame render using the most recently active runtime handle.
schedule_node_update
Schedule an in-place node update using the most recently active runtime.