pub struct RecompositionInfo {
pub instance_id: u64,
pub name: &'static str,
pub file: &'static str,
pub line: u32,
pub manifest_dir: &'static str,
pub recompositions: u64,
}Expand description
A live composable instance, including functions which emit no layout nodes.
Fields
instance_id: u64Identity of this instance for the lifetime of the preview composition thread.
name: &'static strComposable function name.
file: &'static strCompiler-reported source file.
line: u32One-based declaration line.
manifest_dir: &'static strCompiler-reported package directory.
recompositions: u64Body executions after the initial composition.