pub struct SourceLocation {
pub name: &'static str,
pub file: &'static str,
pub line: u32,
pub manifest_dir: &'static str,
/* private fields */
}Expand description
A composable definition active when a layout node was emitted.
Fields
name: &'static strComposable function name.
file: &'static strSource file reported by the compiler.
line: u32One-based declaration line.
manifest_dir: &'static strPackage directory reported by the compiler.
Implementations
Sourceimpl SourceLocation
impl SourceLocation
Sourcepub fn recompositions(&self) -> Option<u64>
pub fn recompositions(&self) -> Option<u64>
Body executions after the initial composition for this composable instance.
Returns None unless a debug preview enabled recomposition tracking.