ConcreteApplierHost

Struct ConcreteApplierHost 

pub struct ConcreteApplierHost<A: Applier + 'static> { /* private fields */ }

Implementations

Source

impl<A: Applier + 'static> ConcreteApplierHost<A>

pub fn new(applier: A) -> Self

pub fn borrow_typed(&self) -> ApplierGuard<'_, A>

pub fn try_borrow_typed(&self) -> Result<ApplierGuard<'_, A>, BorrowMutError>

pub fn try_into_inner(self) -> Result<A, (Self, NodeError)>

Returns the applier after all queued nodes have been disposed.

On failure, returns this host with its pending resources and the error, allowing the caller to repair the cause and retry extraction.

use cranpose_core::{ConcreteApplierHost, MemoryApplier};
let host = ConcreteApplierHost::new(MemoryApplier::new());
assert!(host.try_into_inner().is_ok());