SceneNodeAttachmentScratch

Struct SceneNodeAttachmentScratch 

pub struct SceneNodeAttachmentScratch { /* private fields */ }
Reusable ancestry storage for MemoryApplier::scene_nodes_attached_to_into.

Attachment results are kept only for one batch, so callers can reuse this value without keeping stale attachment results after graph mutations.