pub trait SharedParam {
// Required method
fn same_allocation(&self, other: &Self) -> bool;
}Expand description
A parameter that points at a shared allocation: two that point at the same one are equal without comparing what it holds.
Required Methods
Sourcefn same_allocation(&self, other: &Self) -> bool
fn same_allocation(&self, other: &Self) -> bool
Whether self and other point at the same allocation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".