Structs
- Default
Scheduler - Runtime
- Runtime
Debug Stats - Runtime
Handle - Runtime
Id - Runtime
Thread Local Debug Stats - State
Arena Debug Stats - StateId
- Task
Handle - UiDispatcher
Functions
- current_
runtime_ handle - Gets the current runtime handle from thread-local storage.
- debug_
runtime_ thread_ local_ stats - schedule_
frame - Schedule a new frame render using the most recently active runtime handle.
- schedule_
node_ update - Schedule an in-place node update using the most recently active runtime.