pub struct CapturedCompositionContext { /* private fields */ }Expand description
The composition context inherited by work that is composed in another slot host. Besides composition locals, this carries the source owner scope so a secondary tree cannot outlive the composition that supplied its callbacks.